@@ -20,7 +20,17 @@ Constants for attribute names of the various resources.
 This module contains the top-level config file attributes including those that
 are typically placed in ~/.bangrc.
 """
-from . import creds, server, secgroup, tags, database, ssh_key, loadbalancer
+from . import (  # noqa
+        ansible,
+        creds,
+        server,
+        secgroup,
+        tags,
+        database,
+        ssh_key,
+        loadbalancer,
+        logging,
+        )
 
 #: The stack name.  Its value is used to tag servers and other cloud resources.
 NAME = 'name'
@@ -48,6 +58,9 @@ DEPLOYER_CREDS = 'deployer_credentials'
 #: The top-level key for logging-related configuration options.
 LOGGING = 'logging'
 
+#: A dict containing ansible tuning variables.
+ANSIBLE = 'ansible'
+
 #: Like chicken fried chicken... this is a way to configure the name of the tag
 #: in which the combined stack-role (a.k.a. *name*) will be stored.  By
 #: default, unless this is specified directly in ~/.bangrc, the *name* value
