@@ -22,12 +22,20 @@ import yaml
 
 from . import resources as R, attributes as A
 from .util import log, bump_version_tail, deep_merge_dicts
+from ansible.utils import ask_passwords
 
 
 DEFAULT_CONFIG_DIR = 'bang-stacks'
 DEFAULT_LAUNCH_TIMEOUT_S = 0
 
-RC_KEYS = [A.DEPLOYER_CREDS, 'config_dir', A.NAME_TAG_NAME, A.LOGGING]
+RC_KEYS = [
+        A.DEPLOYER_CREDS,
+        'config_dir',
+        A.NAME_TAG_NAME,
+        A.LOGGING,
+        A.ANSIBLE,
+        ]
+
 ALL_RESERVED_KEYS = RC_KEYS + R.DYNAMIC_RESOURCE_KEYS
 
 
@@ -57,7 +65,7 @@ def read_raw_bangrc():
     bangrc_path = os.path.join(os.environ['HOME'], '.bangrc')
     try:
         with open(bangrc_path) as f:
-            return yaml.load(f)
+            return yaml.safe_load(f)
     except IOError:
         pass
     return {}
@@ -162,11 +170,18 @@ class Config(dict):
             config.filepath = config_paths[0]
         for c in config_paths:
             with open(c) as f:
-                deep_merge_dicts(config, yaml.load(f))
+                deep_merge_dicts(config, yaml.safe_load(f))
         if prepare:
             config.prepare()
         return config
 
+    def _prepare_ansible(self):
+        ansible_cfg = self.get(A.ANSIBLE, {})
+        if ansible_cfg.get(A.ansible.ASK_VAULT_PASS):
+            (_, _, _, vault_pass) = ask_passwords(ask_vault_pass=True)
+            ansible_cfg[A.ansible.VAULT_PASS] = vault_pass
+            self[A.ANSIBLE] = ansible_cfg
+
     def _prepare_dbs(self):
         dbcreds = self.get(R.DATABASE_CREDS, {})
         for db in self.get(R.DATABASES, []):
@@ -398,6 +413,7 @@ class Config(dict):
         self._prepare_dbs()
         self._prepare_servers()
         self._prepare_load_balancers()
+        self._prepare_ansible()
 
     def validate(self):
         """
