@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with bang.  If not, see <http://www.gnu.org/licenses/>.
 import copy
+import functools
 import json
 import multiprocessing
 import os.path
@@ -33,6 +34,15 @@ from .util import log, SharedNamespace, SharedMap
 from . import BangError, resources as R, attributes as A
 
 
+def require_inventory(f):
+    @functools.wraps(f)
+    def wrapper(self, *args, **kwargs):
+        if not self.have_inventory:
+            self.gather_inventory()
+        return f(self, *args, **kwargs)
+    return wrapper
+
+
 class Stack(object):
     """
     Deploys infrastructure/platform resources, then configures any deployed
@@ -54,6 +64,7 @@ class Stack(object):
 
         self.groups_and_vars = SharedMap(self.manager)
         self.lb_sec_groups = SharedMap(self.manager)
+        self.have_inventory = False
 
         """
         Deployers stash inventory data for any newly-created servers in this
@@ -217,7 +228,9 @@ class Stack(object):
 
         """
         self._run('deploy')
+        self.have_inventory = True
 
+    @require_inventory
     def configure(self):
         """
         Executes the ansible playbooks that configure the servers in the stack.
@@ -259,15 +272,21 @@ class Stack(object):
         if ssh_user:
             pb_kwargs['remote_user'] = ssh_user
 
-        # DEBUG: this is like passing ``-vvvv`` to ansible-playbook
-        # ansible.utils.VERBOSITY = 4
+        ansible_cfg = cfg.get(A.ANSIBLE, {})
+        ansible_verbosity = ansible_cfg.get(A.ansible.VERBOSITY, 1)
+        ansible.utils.VERBOSITY = ansible_verbosity
         for playbook in cfg.get(A.PLAYBOOKS, []):
             playbook_path = os.path.join(playbook_dir, playbook)
 
             # gratuitously stolen from main() in ``ansible-playbook``
             stats = callbacks.AggregateStats()
-            playbook_cb = callbacks.PlaybookCallbacks(verbose=1)
-            runner_cb = callbacks.PlaybookRunnerCallbacks(stats, verbose=1)
+            playbook_cb = callbacks.PlaybookCallbacks(
+                    verbose=ansible_verbosity
+                    )
+            runner_cb = callbacks.PlaybookRunnerCallbacks(
+                    stats,
+                    verbose=ansible_verbosity
+                    )
 
             extra_kwargs = {
                     'playbook': playbook_path,
@@ -281,6 +300,7 @@ class Stack(object):
                     # ``host_list`` is used to generate the inventory, but
                     # don't worry, we override the inventory later
                     'host_list': [],
+                    'vault_password': ansible_cfg.get(A.ansible.VAULT_PASS),
                     }
             pb_kwargs.update(extra_kwargs)
             pb = PlayBook(**pb_kwargs)
@@ -311,6 +331,16 @@ class Stack(object):
             if failed:
                 raise BangError("Server configuration failed!")
 
+    def gather_inventory(self):
+        """
+        Gathers existing inventory info.
+
+        Does *not* create any new infrastructure.
+        """
+        self._run('inventory')
+        self.have_inventory = True
+
+    @require_inventory
     def show_inventory(self):
         """
         Satisfies the ``--list`` portion of ansible's external inventory API.
@@ -320,7 +350,6 @@ class Stack(object):
         http://ansible.cc/docs/api.html#external-inventory-scripts
 
         """
-        self._run('inventory')
         print json.dumps(copy.deepcopy(self.groups_and_vars.lists))
 
     def show_host(self, host):
