@@ -33,9 +33,10 @@ from logging.handlers import BufferingHandler
 import boto
 from boto.s3.key import Key
 from logutils.queue import QueueHandler, QueueListener
+from . import attributes as A
 
 
-CONSOLE_LOGGING_FORMAT = '%(asctime)s %(levelname)8s %(processName)s - %(message)s'
+CONSOLE_LOGGING_FORMAT = '%(asctime)s %(levelname)8s %(processName)s - %(message)s'  # noqa
 
 # use the multiprocessing logger so when we start parallelizing the
 # deploys, we have a seamless transition.
@@ -216,15 +217,15 @@ class S3Handler(BufferingHandler):
 
 def initialize_logging(config):
     multiprocessing.current_process().name = 'Stack'
-    cfg = config.get('logging', {})
-    console_level = cfg.get('console_level', 'INFO')
+    cfg = config.get(A.LOGGING, {})
+    console_level = cfg.get(A.logging.CONSOLE_LEVEL, 'INFO')
     log.setLevel(console_level)
 
     # log to s3 if there's a destination specified in the config
-    bucket = cfg.get('s3_bucket')
+    bucket = cfg.get(A.logging.S3_BUCKET)
     if bucket:
         json_formatter = JSONFormatter(config)
-        s3_handler = S3Handler(bucket, cfg.get('s3_prefix', ''))
+        s3_handler = S3Handler(bucket, cfg.get(A.logging.S3_PREFIX, ''))
         s3_handler.setFormatter(json_formatter)
         s3_handler.setLevel(logging.INFO)
 
@@ -248,6 +249,18 @@ def initialize_logging(config):
         qh = QueueHandler(queue)
         log.addHandler(qh)
 
+    # set local_file to an empty string or some other false value to deactivate
+    local_file = cfg.get(A.logging.LOCAL_FILE, 'bang.log')
+    if local_file:
+        local_handler = logging.FileHandler(local_file)
+        local_handler.setFormatter(
+                logging.Formatter(CONSOLE_LOGGING_FORMAT)
+                )
+        local_handler.setLevel(
+                cfg.get(A.logging.LOCAL_FILE_LEVEL, logging.DEBUG)
+                )
+        log.addHandler(local_handler)
+
     # also log to stderr
     if sys.stderr.isatty():
         formatter = ColoredConsoleFormatter(CONSOLE_LOGGING_FORMAT)
@@ -256,6 +269,7 @@ def initialize_logging(config):
     handler = logging.StreamHandler()  # default stream is stderr
     handler.setFormatter(formatter)
     handler.setLevel(logging.DEBUG)
+    log.setLevel(logging.DEBUG)
     log.addHandler(handler)
     log.debug('Logging initialized.')
 
@@ -303,7 +317,7 @@ def parse_args(arg_config, alt_args=None):
     return parser.parse_args(alt_args)
 
 
-SECRET_PATTERN = re.compile(r'(\s*(\S*(password|pwd|key|secret|god)\S*)\s*:\s*)\S+')
+SECRET_PATTERN = re.compile(r'(\s*(\S*(password|pwd|key|secret|god)\S*)\s*:\s*)\S+')  # noqa
 SECRET_WHITELIST = ('ssh_key', 'key_pair')
 
 
